@@ -1,31 +1,20 @@
 /*
-    Copyright (c) 2019 David Edmundson <davidedmundson@kde.org>
+    SPDX-FileCopyrightText: 2019 David Edmundson <davidedmundson@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #pragma once
 
 #include <QObject>
 #include <QVariant>
 
+#include "processes.h"
 #include "unit.h"
 
-namespace KSysGuard {
-
+namespace KSysGuard
+{
 class Process;
+class CGroup;
 
 class Q_DECL_EXPORT ProcessAttribute : public QObject
 {
@@ -42,10 +31,9 @@ public:
     QString id() const;
 
     /**
-     * Controls whether we should fetch process attributes
+     * States whether we should update process attributes
      */
     bool enabled() const;
-    void setEnabled(const bool enable);
 
     /**
      * A translated user facing name for the attribute.
@@ -93,6 +81,16 @@ public:
     bool isVisibleByDefault() const;
     void setVisibleByDefault(bool visible);
 
+    /**
+     * Which update steps are required for this attribute to correctly report its data.
+     *
+     * This can be used to determine which flags should be used when calling
+     * Processes::updateAllProcesses() . By default this will be
+     * Processess::StandardInformation.
+     */
+    Processes::UpdateFlags requiredUpdateFlags() const;
+    void setRequiredUpdateFlags(Processes::UpdateFlags flags);
+
     /**
      * The last stored value for a given process
      */
@@ -108,10 +106,16 @@ public:
      */
     void clearData(KSysGuard::Process *process);
 
+    virtual QVariant cgroupData(KSysGuard::CGroup *cgroup, const QVector<KSysGuard::Process *> &groupProcesses = {}) const;
+
 Q_SIGNALS:
     void dataChanged(KSysGuard::Process *process);
     void enabledChanged(bool enabled);
 
+protected:
+    void connectNotify(const QMetaMethod &signal) override;
+    void disconnectNotify(const QMetaMethod &signal) override;
+
 private:
     class Private;
     QScopedPointer<Private> d;
